@@ -10,11 +10,8 @@ def find():
 				if file.endswith(".PNG" or ".png"):
 					image = file
 		if pyautogui.locateOnScreen(image) != None:
-			found = True
 			print ("True")
 			sleep(0.5)
 		else:
-			found = False
 			print ("False")
-			sleep(0.5)
-find()
\ No newline at end of file
+			sleep(0.5)
\ No newline at end of file
